
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.25.1',
    'branch_nick': 'patch-0-Release__1_25_1_preparation',
    'revision_id': '4c5f830d048a0bea9c1c3e078eceb244d5946b7a',
    'revno': 10480
}
